@@ -43,6 +43,9 @@ function(x, y, filename='', snap='near', datatype=NULL, ...) {
 	leg <- out@legend
 
 	e <- intersect(extent(x), extent(y))
+	if (is.null(e)) {
+		stop('extents do not overlap')
+	}
 	e <- alignExtent(e, x, snap=snap)
 	out <- setExtent(out, e, keepres=TRUE)
 	
@@ -62,7 +65,7 @@ function(x, y, filename='', snap='near', datatype=NULL, ...) {
 	nr <- row2 - row1 + 1
 	
 	if (is.null(datatype)) { 
-		datatype <- unique(dataType(x))
+		datatype <- unique(c(dataType(x), 'INT2S'))
 		if (length(datatype) > 1) {
 			datatype <- .commonDataType(datatype)
 		}
