@@ -12,7 +12,7 @@
 	} else if (missing(field)) {
 		if (.hasSlot(obj, 'data')) {
 			putvals <- obj@data
-			cn <- .goodNames(c('ID', colnames(putvals)))
+			cn <- validNames(c('ID', colnames(putvals)))
 			cn[1] <- 'ID'
 			putvals <- data.frame(ID=1:nrow(putvals), putvals)
 			colnames(putvals) <- cn	
@@ -101,7 +101,7 @@
 		return(resxy) 
 	}
 	for (i in 1:nrow(xyxy)) {
-		xy <- raster:::.intersectSegments(xyxy[i,1], xyxy[i,2], xyxy[i,3], xyxy[i,4], line[1,1], line[1,2], line[2,1], line[2,2] )
+		xy <- .intersectSegments(xyxy[i,1], xyxy[i,2], xyxy[i,3], xyxy[i,4], line[1,1], line[1,2], line[2,1], line[2,2] )
 		if (!is.na(xy[1])) {
 			resxy <- rbind(resxy, xy)
 		}
@@ -174,8 +174,8 @@
 	
 	rstr <- raster(rstr)
 	
-	if (projection(p) != "NA") {
-		projection(rstr) = projection(p)
+	if (!is.na(projection(p))) {
+		projection(rstr) <- projection(p)
 	}
 
 # check if bbox of raster and p overlap
@@ -188,7 +188,7 @@
 	}
 	
 	npol <- length(p@polygons)
-	pvals <- raster:::.getPutVals(p, field, npol, mask)
+	pvals <- .getPutVals(p, field, npol, mask)
 	putvals <- pvals[,1]
 	if (ncol(pvals) > 1) {
 		rstr@data@isfactor <- TRUE
@@ -233,7 +233,7 @@
 		
 	lxmin <- min(spbb[1,1], rsbb[1,1]) - xres(rstr)
 	lxmax <- max(spbb[1,2], rsbb[1,2]) + xres(rstr)
-	if (getCover) { return (raster:::.polygoncover(rstr, filename, polinfo, lxmin, lxmax, pollist, ...)) }
+	if (getCover) { return (.polygoncover(rstr, filename, polinfo, lxmin, lxmax, pollist, ...)) }
 
 	adj <- 0.5 * xres(rstr)
 
@@ -470,7 +470,7 @@
 						rvtmp <- rv1
 						if ( sum(x[-length(x)] == x[-1]) > 0 ) {
 					# single node intersection going out of polygon ....
-							spPnts <- xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr)), TRUE)
+							spPnts <- SpatialPoints(xyFromCell(rstr, cellFromRowCol(rstr, rep(r, ncol(rstr)), 1:ncol(rstr))))
 							spPol <- SpatialPolygons(list(Polygons(list(mypoly), 1)))
 							over <- over(spPnts, spPol)
 							if ( subpol[i, 5] == 1 ) {
