@@ -420,7 +420,8 @@ function(object, v, cell, band) {
 	if (setminmax) {	
 		b <- new("GDALRasterBand", gdal, band)
 		statistics <- c(object@data@min, object@data@max, NA, NA)
-		rgdal:::.gd_SetStatistics(b, statistics)
+		.gd_SetStatistics <- eval(parse(text="rgdal:::.gd_SetStatistics"))
+		.gd_SetStatistics(b, statistics)
 	}
 
 	return(object)
