@@ -47,7 +47,8 @@
 		
 		for (i in 1:nl) {
 			b <- new("GDALRasterBand", x@file@transient, i)
-			rgdal:::.gd_SetStatistics(b, as.double(statistics[i,]))
+			.gd_SetStatistics <- eval(parse(text="rgdal:::.gd_SetStatistics"))
+			.gd_SetStatistics(b, as.double(statistics[i,]))
 		}
 	}
 	
