@@ -33,7 +33,7 @@
 		}
 	} else {
 		if (!overwrite & (file.exists(filename) | file.exists(fnamevals))) {
-			stop(paste(filename,"exists.","use 'overwrite=TRUE' if you want to overwrite it")) 
+			stop(paste(filename,"or", fnamevals, "exists.","use 'overwrite=TRUE' if you want to overwrite it")) 
 		}
 	}
 	
@@ -79,6 +79,7 @@
 	close(x@file@con)
 #	fnamevals <- .setFileExtensionValues(x@file@name)
 #	attr(x@file, "con") <- file(fnamevals, "rb")
+
 	x@data@haveminmax <- TRUE
 	if (x@file@dtype == "INT") {
 		x@data@min <- round(x@data@min)
@@ -87,6 +88,10 @@
 #		x@data@min <- as.logical(x@data@min)
 #		x@data@max <- as.logical(x@data@max)
 	}
+	
+	#x@data@min[!is.finite(x@data@min)] <- NA
+	#x@data@max[!is.finite(x@data@max)] <- NA
+	
 	hdr(x, .driver(x)) 
 	filename <- .setFileExtensionValues(filename(x), x@file@driver)
 	
